.. collective.restapi.pam documentation master file, created by
   sphinx-quickstart on Fri Oct  6 16:44:56 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to collective.restapi.pam's documentation!
==========================================================

.. include:: ../../README.rst


Contents
--------

.. toctree::
   :maxdepth: 2

   translations
